@@ -1,6 +1,7 @@
 #include <assert.h>
 #include <stdio.h>
 #include <stdlib.h>
+#include <wlr/backend.h>
 #include <wlr/types/wlr_output_management_v1.h>
 #include <wlr/util/log.h>
 #include "wlr-output-management-unstable-v1-protocol.h"
@@ -866,7 +867,7 @@ static void manager_send_head(struct wlr_output_manager_v1 *manager,
 		head_send_mode(head, head_resource, mode);
 	}
 
-	if (output->current_mode == NULL) {
+	if (head->state.mode == NULL && head->state.enabled) {
 		// Output doesn't have a fixed mode set. Send a virtual one.
 		head_send_mode(head, head_resource, NULL);
 	}
@@ -926,7 +927,7 @@ static bool manager_update_head(struct wlr_output_manager_v1 *manager,
 		}
 	}
 
-	if (next->mode == NULL && !head_has_custom_mode_resources(head)) {
+	if (next->mode == NULL && next->enabled && !head_has_custom_mode_resources(head)) {
 		struct wl_resource *resource;
 		wl_resource_for_each(resource, &head->resources) {
 			head_send_mode(head, resource, NULL);
@@ -1027,3 +1028,25 @@ void wlr_output_head_v1_state_apply(
 	wlr_output_state_set_adaptive_sync_enabled(output_state,
 		head_state->adaptive_sync_enabled);
 }
+
+struct wlr_backend_output_state *wlr_output_configuration_v1_build_state(
+		const struct wlr_output_configuration_v1 *config, size_t *states_len) {
+	*states_len = wl_list_length(&config->heads);
+	struct wlr_backend_output_state *states = calloc(*states_len, sizeof(states[0]));
+	if (states == NULL) {
+		return NULL;
+	}
+
+	size_t i = 0;
+	const struct wlr_output_configuration_head_v1 *config_head;
+	wl_list_for_each(config_head, &config->heads, link) {
+		struct wlr_backend_output_state *state = &states[i];
+		i++;
+
+		state->output = config_head->state.output;
+		wlr_output_state_init(&state->base);
+		wlr_output_head_v1_state_apply(&config_head->state, &state->base);
+	}
+
+	return states;
+}
