@@ -1,7 +1,3 @@
-#ifndef _POSIX_C_SOURCE
-#define _POSIX_C_SOURCE 200809L
-#endif
-
 #include <assert.h>
 #include <stdlib.h>
 #include <wayland-server-core.h>
@@ -400,6 +396,7 @@ static void pointer_gestures_v1_bind(struct wl_client *wl_client, void *data,
 static void handle_display_destroy(struct wl_listener *listener, void *data) {
 	struct wlr_pointer_gestures_v1 *gestures =
 		wl_container_of(listener, gestures, display_destroy);
+	wl_signal_emit_mutable(&gestures->events.destroy, NULL);
 	wl_list_remove(&gestures->display_destroy.link);
 	wl_global_destroy(gestures->global);
 	free(gestures);
@@ -424,6 +421,8 @@ struct wlr_pointer_gestures_v1 *wlr_pointer_gestures_v1_create(
 		return NULL;
 	}
 
+	wl_signal_init(&gestures->events.destroy);
+
 	gestures->display_destroy.notify = handle_display_destroy;
 	wl_display_add_destroy_listener(display, &gestures->display_destroy);
 
